==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>Pridať vlastnú vlastnosť</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Názov:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Hodnota:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Zobraziť Z súradnice</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Zobrazenie vlastností aktuálneho bloku a aktuálnej vrstvy</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.js" line="+1320"/>
        <source>*VARIES*</source>
        <translation>*Rôzne*</translation>
    </message>
    <message>
        <location line="-1132"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+150"/>
        <source>No Selection</source>
        <translation>Nič nie je vybraté</translation>
    </message>
    <message>
        <source>Geometry</source>
        <translation type="vanished">Geometria</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Špeciálne vlastnosti</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Závislé prvky</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Vlastné</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Odstrániť vlastnosť z vybraných prvkov</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translation>Všetko</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add custom property to selected objects</source>
        <translation>Pridať vlastné vlastnosti k vybraným prvkom</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Auto</source>
        <translation>automatický</translation>
    </message>
    <message>
        <location line="+123"/>
        <source>Use auto measurement</source>
        <translation>Použiť automatické meranie</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>Áno</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location line="+320"/>
        <source>Widgets</source>
        <translation>Pomôcky</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>Výber:</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Všeobecné</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Všeobecné vlastnosti</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>Farba:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Handle:</source>
        <translation>Identifikátor:</translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translation type="vanished">Presunúť výber do Novej vrstvy</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>Linetype Scale:</source>
        <translation>Mierka typu čiary:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Chránené:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>Pridať vlastnú vlastnosť</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Názov:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Hodnota:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Zobraziť Z súradnice</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Zobrazenie vlastností aktuálneho bloku a aktuálnej vrstvy</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Allow adding custom properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Always show all properties (this may slow down selection of entities)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PropertyEditor.js" line="+1392"/>
        <source>*VARIES*</source>
        <translation>*Rôzne*</translation>
    </message>
    <message>
        <location line="-1199"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+151"/>
        <source>No Selection</source>
        <translation>Nič nie je vybraté</translation>
    </message>
    <message>
        <source>Geometry</source>
        <translation type="vanished">Geometria</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Špeciálne vlastnosti</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Závislé prvky</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Vlastné</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translation>Zoznam</translation>
    </message>
    <message>
        <location line="+77"/>
        <source>Remove this property from selected objects</source>
        <translation>Odstrániť vlastnosť z vybraných prvkov</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translation>Všetko</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add custom property to selected objects</source>
        <translation>Pridať vlastné vlastnosti k vybraným prvkom</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show all properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+117"/>
        <source>Auto</source>
        <translation>automatický</translation>
    </message>
    <message>
        <location line="+128"/>
        <source>Use auto measurement</source>
        <translation>Použiť automatické meranie</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>Áno</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location line="+336"/>
        <source>Widgets</source>
        <translation>Pomôcky</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>Výber:</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Všeobecné</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Všeobecné vlastnosti</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>Farba:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Handle:</source>
        <translation>Identifikátor:</translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translation type="vanished">Presunúť výber do Novej vrstvy</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>Linetype Scale:</source>
        <translation>Mierka typu čiary:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Chránené:</translation>
    </message>
</context>
</TS>
